@@ -2,7 +2,7 @@
 
 __author__ = """Qiusheng Wu"""
 __email__ = 'giswqs@gmail.com'
-__version__ = '0.0.2'
+__version__ = '0.0.3'
 
 
-from .mapwidget import *
\ No newline at end of file
+from .leaflet import *
